package EFS::CLI::Logfile;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        id => { type => SCALAR },
    });

    my $history_rs = $class->get_resultset( q{History} );
    my $history = $history_rs->retrieve_assert( id => $args{id} );

    my $logfile = $history->logfile();

    if ( $logfile =~ m{\A /efs/dev/efs/logs - ([^/]+)/}msx ) {

        my $cell_rs = $class->get_resultset( q{Cell} );
        my $cell = $cell_rs->retrieve_bynames_assert( name => $1 );

        return EFS::RPC->execute(
            cell   => $cell,
            class  => $class,
            method => q{history_rpc},
            args   => [ $logfile ],
        );

    } elsif ( $logfile =~ m{\A $EFS::logroot}msx ) {

        my $efshost = $history->efshost();

        my $efsserver_rs = $class->get_resultset( q{EFSServer} );
        my ($efsserver) = $efsserver_rs->search({ name => $efshost });

        if ( not $efsserver ) {
            die qq{No such EFS server $efshost\n};
        }

        return EFS::RPC->execute_on(
            efsservers => [ $efsserver ],
            class      => $class,
            method     => q{history_rpc},
            args       => [ $logfile ],
        );

    } else {
        return die qq{Unrecognized logfile path: $logfile\n};
    }

}

sub history_rpc {

    my $class   = shift;
    my $logfile = shift;

    my @logfile = ();

    my $cat_cmd;

    if ( $logfile =~ m/\.gz \z/msx ) {
        $cat_cmd = qq{gunzip -c $logfile};
    } else {
        $cat_cmd = qq{cat $logfile};
    }

    if ( -f $logfile ) {
        @logfile = qx{ $cat_cmd };
        $CHILD_ERROR and die qq{Unable to display logfile $logfile\n};
    } else {
        die qq{Missing logfile for history record\n};
    }

    if ( @logfile ) {
        STDOUT->print(@logfile);
        if ( $logfile[-1] !~ m/\n \z/msx ) {
            STDOUT->print(qq{\n});
        }
    } else {
        STDERR->print( qq{Logfile $logfile is empty\n} );
    }

    return 1;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
