package EFS::CLI::Parameter;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name  => { type => SCALAR },
        value => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($parameter) = $resultset->search( { name => $args{name} } );

    if ( $parameter ) {

        STDOUT->print( qq{Parameter '$parameter' is already defined\n} );

        if ( $parameter->value ne $args{value} ) {
            $parameter->set_column( value => $args{value} );
            $parameter->update;
            STDOUT->print( qq{Updated value of parameter '$args{name}'\n} );
        }

    }
    else {

        $parameter = $resultset->create({
            name  => $args{name},
            value => $args{value},
        });

        STDOUT->print( qq{Defined parameter '$args{name}'\n} );

    }

    return $parameter;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my $parameter =
        $resultset->retrieve_bynames_assert( name => $args{name} );

    $parameter->delete;

    STDOUT->print( qq{Undefined parameter '$args{name}'\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( not $args{name} ) {
        $class->display_objects( objects => [ $resultset->all ] );
        return 1;
    }

    my $parameter =
        $resultset->retrieve_bynames_assert( name => $args{name} );

    $class->display_objects( objects => [$parameter] );

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{parameter} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
