package EFS::DBI::Result::History;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Result};

use EFS::FQDN qw( fqdn );

use Params::Validate qw( :all );

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix TimeStamp Core/ );

__PACKAGE__->table( q{history} );

our @other_keys =
    ( # Other keys from all the other tables
        qw( region campus location cell
            metaproj project release install
            releasealias target hosttype stage
            username groupname userid groupid
            platform platformalias
            platforminstance platforminstancealias
            backwards emulates
            fileserver fileshare fileqtree filetype
            efsserver domain home
            business division pod hostclass cabinet
            feature ffrule ) );

our @history_values =
    ( # History specific columns
        qw( command request logfile authuser
            efshost efsversion status pid parent )
    );

# XXX: This is a case where we make use of the column groups in cdbi
# __PACKAGE__->columns( Keys      => @other_keys );
# __PACKAGE__->columns( Values    => @history_values );
# __PACKAGE__->columns( Essential => @other_keys, @history_values );

__PACKAGE__->add_columns( @other_keys, @history_values );
__PACKAGE__->add_columns(
    id => { __PACKAGE__->get_id_column_attrs },
    starttime => {
        data_type     => q{datetime},
        set_on_create => 1,
    },
    endtime => {
        data_type     => q{datetime},
        set_on_update => 1,
    },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{history_seq} );

__PACKAGE__->has_many( diststats => q{EFS::DBI::Result::DistStats} );

__PACKAGE__->belongs_to( parent => __PACKAGE__ );

sub children {
    my $self = shift;
    my $resultset = $self->get_resultset;
    my @children = $resultset->search({ parent => $self->id });
    return @children;
}

push @history_values, q{starttime}, q{endtime};

sub create_child {

    my $self = shift;
    my (%args) = @_;

    my %values = ();

    foreach my $key ( @other_keys ) {
        if ( exists $args{$key} ) {
            $values{$key} = $args{$key};
        }
        elsif ( $self->$key ) {
            $values{$key} = $self->$key;
        }
    }

    my $resultset = $self->get_resultset;

    my $child = $resultset->create({
        # This one we assert,
        parent     => $self->id,
        # These we inherit,
        command    => $self->command,
        request    => $args{request} || $self->request,
        authuser   => $self->authuser,
        efsversion => $self->efsversion,
        # These we set automatically,
        efshost    => fqdn,
        pid        => $PID,
        # The rest are passed in by the caller
        %values,
    });

    return $child;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
