package EFS::DBI::ResultSet::Cabinet;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {

    my $class = shift;
    my %data  = @_;

    if ( exists $data{cabinet} ) {
        if ( $data{cabinet} !~ m{\A \w+ / \w+ / \w+ / \w+ \z}msx ) {
            die(
                qq{Invalid cabinet name: '$data{cabinet}'\n},
                qq{Must match the format 'floor/room/bay/cabinet'\n},
            );
        }
    }

    return 1;

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        location => { type => SCALAR },
        name     => { type => SCALAR },
    });

    # XXX: Should we make these classes inherit from EFS::DBI, too?
    my $location_rs = EFS::DBI->get_resultset( q{Location} );

    my $location = $location_rs->retrieve_bynames_assert(
        name => $args{location},
    );

    my ($cabinet) = $self->search({
        location => $location->id,
        name     => $args{name},
    });

    if ( not $cabinet ) {
        my $object_id = join( q{/}, $args{location}, $args{name} );
        die qq{No such cabinet '$object_id'\n};
    }

    return $cabinet;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:

