package EFS::DBI::ResultSet::Campus;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {
    my $class = shift;
    my %data = @_;
    return 1 unless exists $data{campus};
    ## no critic ProhibitEnumeratedClasses
    # we really do want a-z here; [:lower:] would be effected by locale
    $data{campus} =~ m/\A [a-z]+ \z/msx || die(
        qq{Invalid campus '$data{campus}'\n},
        qq{Must consist solely of lower case letters (a-z)\n}
    );
    return;
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        region => { type => SCALAR, optional => 1 },
        name   => { type => SCALAR },
    });

    my $campus;

    if ( $args{region} ) {

        my $region_rs = EFS::DBI->get_resultset( q{Region} );

        my $region = $region_rs->retrieve_bynames_assert( name => $args{region} );

        ($campus) = $self->search({
            region => $region->id,
            name   => $args{name},
        });

        if ( not $campus ) {
            die qq{No such campus $args{region}/$args{name}\n};
        }

    } else {

        ($campus) = $self->search({ name => $args{name} });

        if ( not $campus ) {
            die qq{No such campus $args{name}\n};
        }

    }

    return $campus;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
