package EFS::DBI::ResultSet::Division;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {
    my $class = shift;
    my %data = @_;
    return 1 unless exists $data{division};
    ## no critic ProhibitEnumeratedClasses
    # we really do want a-z here; [:lower:] would be effected by locale
    $data{division} =~ m/\A [a-z]+ \z/msx || die(
        qq{Invalid division '$data{division}'\n},
        qq{Must consist solely of lower case letters (a-z)\n}
    );
    return;
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        business => { type => SCALAR },
        name     => { type => SCALAR },
    });

    my $business_rs = EFS::DBI->get_resultset( q{Business} );

    my $business = $business_rs->retrieve_bynames_assert(
        name => $args{business},
    );

    my ($division) = $self->search({
        business => $business->id,
        name     => $args{name},
    });

    if ( not $division ) {
        die qq{No such division '$args{name}' in business '$args{business}'\n};
    }

    return $division;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
