package EFS::DBI::ResultSet::ForbiddenFileRule;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {

    my $class = shift;

    my %data = @_;

    if ( exists $data{ffrule} ) {
        ## no critic ProhibitEnumeratedClasses
        # we really do want a-z here; [:lower:] would be effected by locale
        $data{ffrule} =~ m/\A [a-z]+ \z/msx || die(
            qq{Invalid forbidden_file_rule '$data{ffrule}'\n},
            qq{Must consist solely of lower case letters (a-z)\n}
        );
    }

    if ( exists $data{regex} ) {
        # XXX: What's the cleanest way to validate a regex string?
    }

    return 1;

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
    });

    my ($ffrule) = $self->search({ name => $args{name} });

    if ( not $ffrule ) {
        die qq{No such forbidden file rule $args{name}\n};
    }

    return $ffrule;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
