package EFS::DBI::ResultSet::Install;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {
    my $class = shift;
    my %data  = @_;
    if ( not exists $data{install} ) {
        return 1;
    }
    if ( $data{install} eq q{common} ) {
        return 1;
    }
    return EFS::DBI::ResultSet::Platform->validate_data( platform => $data{install} );
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        metaproj  => { type => SCALAR },
        project   => { type => SCALAR },
        release   => { type => SCALAR },
        name      => { type => SCALAR },
        disabled  => { type => BOOLEAN, optional => 1 },
        destroyed => { type => BOOLEAN, optional => 1 },
    });

    my $release_rs = EFS::DBI->get_resultset( q{Release} );

    my $release = $release_rs->retrieve_bynames_assert(
        metaproj => $args{metaproj},
        project  => $args{project},
        name     => $args{release},
        disabled => $args{disabled},
    );

    my ($install) = $self->search({
        release => $release->id,
        name    => $args{name},
    });

    if ( not $install ) {
        die qq{No such install '$release/$args{name}'\n};
    }

    if ( not $args{disabled} ) {
        $install->assert_not_disabled;
    }

    if ( not $args{destroyed} ) {
        $release->assert_not_destroyed;
    }

    return $install;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
