package EFS::Diststate::Metaproj;

use strict;
use warnings;
use English;

use Moose;
use Params::Validate qw( :all );

extends qw(EFS::Diststate);
use EFS::Diststate::Project;


has metaproj => (
    is => 'rw',
);

has project_diststate => (
    is => 'rw',
);

sub BUILD {

    my ($self,@args) = @_;

    my (%args) = validate( @args, {
        metaproj => {
            type => OBJECT,
            isa  => q{EFS::DBI::Result::Metaproj}
        },
    });

    my $metaproject = $self->metaproj = $args{metaproj};

    my @projects = $metaproject->projects;

    for my $project (@projects) {
        $self->project_diststate->{ $project->name } =
            EFS::Diststate::Project->new( {project => $project} );
    }

    return;
}

sub related_item { return shift->get_metaproj }

sub subitem_diststates {
    my ( $self ) = @_;
    return values %{ $self->project_diststate };
}

sub metaprojects_needing_update {

    my $self = shift;

    my (%args) = validate( @_, {
        cells => { type => ARRAYREF, optional => 1 },
    });

    if ( $self->needs_update(%args) ) {
        return $self;
    }
    else {
        return ();
    }
}

sub metaprojects_updated {

    my $self = shift;

    my (%args) = validate( @_, {
        cells => { type => ARRAYREF, optional => 1 },
    });

    if ( $self->has_been_updated(%args) ) {
        return $self;
    }
    else {
        return ();
    }
}

sub _subitem_type { return q{project} }


1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
