package EFS::Username;

use strict;
use warnings;
use English;

use Moose;

use Params::Validate qw( :all );

has q{name} => (
    is       => q{ro},
    isa      => q{Str},
    required => 1,
);
with q{EFS::Stringification};

has q{groups} => (
    is         => q{ro},
    isa        => q{ArrayRef[Str]},
    lazy_build => 1,
    init_arg   => undef,
    auto_deref => 1,
);

sub _build_groups {

    my $self  = shift;

    my $name = $self->name;

    my @groups = ( $self->primary_groupname );

    setgrent || die qq{Unable to setgrent: $ERRNO\n};

    while ( my @getgrent = getgrent ) {
        if ( $getgrent[3] =~ m{ \b $name \b }msx ) {
            push @groups, $getgrent[0];
        }
    }

    endgrent; # No return value, supposedly...

    return \@groups;
}

has q{_pwnam} => (
    is         => q{ro},
    isa        => q{ArrayRef[Str]},
    lazy_build => 1,
    init_arg   => undef,
);

has q{_primary_grgid} => (
    is         => q{ro},
    isa        => q{ArrayRef[Str]},
    lazy_build => 1,
    init_arg   => undef,
);

sub _build__pwnam {

    my $self = shift;

    my $name  = $self->name;
    my @pwnam = getpwnam( $name )
        or die qq{No such username '$name'\n};

    return \@pwnam;

}

sub _build__primary_grgid {

    my $self = shift;

    my $pwnam   = $self->_pwnam;
    my $groupid = $pwnam->[3];

    my @getgrgid = getgrgid($groupid) or
        die qq{No such group ID '$groupid'\n};

    return \@getgrgid;

}

{

    sub BUILD {
        return shift->_primary_grgid;
    }


    sub as_string {
        return shift->name;
    }

    sub userid {
        return shift->_pwnam->[2];
    }

    sub primary_groupname {
        return shift->_primary_grgid->[0];
    }

    sub is_member_of {
        my $self = shift;
        my $group = shift;
        return grep { $group eq $_ } $self->groups;
    }

}

no Moose;
__PACKAGE__->meta->make_immutable;
1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
