#!/usr/bin/env perl

use strict;
use warnings;
use English;

use IO::File;

use lib q{test/lib};
use EFS::Test::Config;
use Test::More qw( no_plan );
use File::Slurp;

use DBI;

my $config = EFS::Test::Config->new;

my $connect   = $config->get_value( q{Database}, q{connect} );
my $dbouser   = $config->get_value( q{Database}, q{dbouser} );
my $dbopasswd = $config->get_value( q{Database}, q{dbopasswd} );
my $rwuser    = $config->get_value( q{Database}, q{rwuser} );
my $rwpasswd  = $config->get_value( q{Database}, q{rwpasswd} );
my $rouser    = $config->get_value( q{Database}, q{rouser} );
my $ropasswd  = $config->get_value( q{Database}, q{ropasswd} );
my $dbvendor  = $config->get_value( q{Database}, q{dbvendor} );

my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );
my $sshcmd        = $config->get_value( q{Global},        q{sshcmd} );

my $perl5lib = $ENV{PERL5LIB} || q{};
local $ENV{PERL5LIB} = qq{./blib/lib:$perl5lib};

system(q{./util/efs_bootstrap_database } .
       qq{--connect '$connect' } .
       qq{--dbouser $dbouser --dbopasswd $dbopasswd } .
       qq{--rwuser $rwuser --rwpasswd $rwpasswd } .
       qq{--rouser $rouser --ropasswd $ropasswd } .
       q{--verbose} );
ok( $CHILD_ERROR == 0, q{efs_bootstrap_database} );

system( qq{$sshcmd $rdc_efsserver mkdir -p /var/efs/etc} );
ok( $CHILD_ERROR == 0, qq{mkdir $rdc_efsserver:/var/efs} );

system( qq{$sshcmd $rdc_efsserver mkdir -p /etc/efs} );
ok( $CHILD_ERROR == 0, qq{mkdir $rdc_efsserver:/etc/efs} );

system( qq{rsync --rsh='$sshcmd' -avz }
            . qq{/etc/efs/server.conf $rdc_efsserver:/etc/efs/server.conf} );
ok( $CHILD_ERROR == 0, qq{rsync /etc/efs/server.conf -> $rdc_efsserver} );

system( qq{rsync --rsh='$sshcmd' -avz }
            . qq{/var/efs/etc/passwd/ $rdc_efsserver:/var/efs/etc/passwd} );
ok( $CHILD_ERROR == 0, qq{rsync /var/efs/etc/passwd -> $rdc_efsserver} );

1;
