#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $region = q{testregion};

$test->efs_test_command(
    name    => q{Verifying that the region doesn't exist...},
    command => qq{efs display region $region},
    expect  => [ qq{No such region '$region'}, ],
    bail    => 1,
    not     => 1,
);

$test->efs_test_command(
    name    => q{Define a bogus region},
    command => q{efs define region UPPERCASE 'test region'},
    expect  => [
        q{Invalid region 'UPPERCASE'},
        q{Must consist solely of lower case letters (a-z)},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
    not => 1,
);

$test->efs_test_command(
    name    => qq{Define the region $region},
    command => qq{efs define region $region 'temp region'},
    expect  => [ qq{Defined region '$region'}, ],
);

$test->efs_test_command(
    name    => qq{Define the region $region, again},
    command => qq{efs define region $region 'test region'},
    expect  => [
        qq{Region '$region' is already defined},
        qq{Updated description of region $region},
    ],
);

$test->efs_test_command(
    name    => q{Set an attribute for the region},
    command => ( qq{efs setattr region $region foo bar}, ),
    expect  => [
        qq{For region '$region', defined attribute as:},
        q{'foo' => 'bar'},
    ],
);

$test->efs_test_command(
    command => qq{efs display region $region},
    expect  => [
        qr{Region \s+ Description}msx,
        qr{=+}msx,
        qr{$region \s+ test \s+ region}msx,
        qr{Region \s+ Attribute \s+ Value}msx,
        qr{=+}msx,
        qr{$region \s+ foo \s+ bar}msx,
    ],
);

$test->efs_test_command(
    command => qq{efs undef region $region},
    expect  => [ qq{Undefined region $region}, ],
);

$test->efs_test_command(
    command => qq{efs history region $region -count 4},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ region \s+ $region}msx,
        qr{define \s+ region \s+ $region}msx,
        qr{setattr \s+ region \s+ $region \s+ foo \s+ bar}msx,
        qr{undef \s+ region \s+ $region}msx,
    ],
);

