#!/usr/bin/env perl

use strict;
use warnings;
use English;

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test;
use EFS::Test::Config;

use Test::More;

my $test = EFS::Test->new;
my $config = EFS::Test::Config->new;

my $ldc_efsserver = $config->get_value( q{LocalDevCell}, q{efsserver} );
my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs backup database},
    not     => 1,
    expect  => [
        qq{Unable to backup database: No database_primary parameter},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define parameter database_primary $ldc_efsserver},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs backup database},
    expect  => [
        qq{Created directory /var/efs/db/backup},
        qr{Database dumped to efs-\d{8}-\d{6}.sql.bz2}ms,
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define parameter database_secondary $rdc_efsserver},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs backup database},
    expect  => [
        qr{Database dumped to efs-\d{8}-\d{6}.sql.bz2}ms,
        qq{Created directory /var/efs/db},
        qq{Copied mysql backup data to $rdc_efsserver},
    ],
);

# Generate additional backups, then test that we get rid of extra ones

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs backup database && efs backup database && efs backup database},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs backup database},
    expect  => [
        qr{Database dumped to efs-\d{8}-\d{6}.sql.bz2}ms,
        qq{Removing these old backups:},
        qr{/var/efs/db/backup/efs-\d{8}-\d{6}.sql.bz2}ms,
        qq{Copied mysql backup data to $rdc_efsserver},
    ],
);

done_testing();

1;
